#!/bin/bash
######################################################################
#
#   tcar - The CentOS Artwork Repository
#   Copyright © 2014 The CentOS Artwork SIG
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#   General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#   Alain Reguera Delgado <alain.reguera@gmail.com>
#   39 Street No. 4426 Cienfuegos, Cuba.
#
######################################################################

# Interpret option arguments passed to `tcarlib' script and calls actions
# accordingly.
function tcarlib_getOptions {

    # Define short options we want to support.
    local ARGSS="h,v,q,y,d,f:"

    # Define long options we want to support.
    local ARGSL="help,version,quiet,yes,debug,filter:"

    # Divide command-line arguments in order to process them. Here the
    # command-line is divided in "common arguments" and "specific
    # arguments". Common arguments begin after the main command (e.g.,
    # tcarlib.sh) and end before the first non-option argument provided
    # in the command-line. Specific arguments include the first
    # non-option argument and all arguments after it.
    ARGUMENTS=''; local ARGUMENT='' SPECIFIC_ARGUMENTS='' COMMON_ARGUMENTS=''
    for ARGUMENT in ${@};do
        if [[ ${ARGUMENT} =~ ^- ]];then
            if [[ -n ${COMMON_ARGUMENTS} ]];then
                COMMON_ARGUMENTS="${ARGUMENT} ${COMMON_ARGUMENTS}"
            else
                COMMON_ARGUMENTS="${ARGUMENT}"
            fi
            shift 1; continue
        else
            SPECIFIC_ARGUMENTS="${@}"
            break
        fi
    done

    # Redefine local arguments using getopt(1) command parser.
    tcarlib_setArguments "${COMMON_ARGUMENTS}"

    # Reset positional parameters on this function, using output
    # produced from (getopt) arguments parser.
    eval set -- "${ARGUMENTS}"

    # Look for options passed through command-line.
    while true; do

        case "${1}" in

            -h | --help )
                tcarlib_printHelp
                ;;

            -v | --version )
                tcarlib_printVersion
                ;;

            -q | --quiet )
                SCRIPT_FLAG_QUIET='true'
                shift 1
                ;;

            -y | --yes )
                SCRIPT_FLAG_YES='true'
                shift 1
                ;;

            -d | --debug )
                SCRIPT_FLAG_DEBUG='true'
                shift 1
                ;;

            -f | --filter )
                SCRIPT_FLAG_FILTER=${2}
                shift 2
                ;;

            -- )
                shift 1
                break
                ;;
        esac
    done

    # Redefine arguments using specific arguments. Only
    # paths should remain as arguments at this point.
    ARGUMENTS="${SPECIFIC_ARGUMENTS}"

}
