#!/bin/bash
######################################################################
#
#   tcar - The CentOS Artwork Repository
#   Copyright © 2014 The CentOS Artwork SIG
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#   General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#   Alain Reguera Delgado <alain.reguera@gmail.com>
#   39 Street No. 4426 Cienfuegos, Cuba.
#
######################################################################

function tcarlib_setConfigOption {

    local OPTION="${1}"

    case ${OPTION} in

        url )
            URL="$(tcarlib_getConfigValue)"

            local URL_TITLE=''  ; tcarlib_setConfigOption 'url-title'

            tcarlib_setConfigOption 'url-l10n'
            tcarlib_setConfigOption 'url-html'
            ;;

        url-title )
            URL_TITLE="$(tcarlib_getConfigValue)"
            [[ -z ${URL_TITLE} ]] && URL_TITLE=${URL}
            ;;

        url-l10n )
            local URL_L10N="$(tcarlib_getConfigValue)"
            if [[ ${URL_L10N} == 'yes' ]];then
                if [[ ${SCRIPT_LANG_LL} != 'en' ]];then
                    URL=$(echo ${URL} | sed -r "s,/*$,/${SCRIPT_LANG_LL}/,")
                fi
            fi
            ;;

        url-html )
            local URL_HTML="$(tcarlib_getConfigValue)"
            if [[ -n ${URL_HTML} ]];then
                if [[ ${URL_HTML} == 'yes' ]];then
                    URL="<a href=\"${URL}\">${URL_TITLE}</a>"
                fi
            fi
            ;;

        email )
            EMAIL="$(tcarlib_getConfigValue)"
            local EMAIL_TITLE=''    ; tcarlib_setConfigOption 'email-title'

            tcarlib_setConfigOption 'email-l10n'
            tcarlib_setConfigOption 'email-html'
            ;;

        email-title )
            EMAIL_TITLE=$(tcarlib_getConfigValue)
            [[ -z ${EMAIL_TITLE} ]] && EMAIL_TITLE=${EMAIL}
            ;;

        email-l10n )
            local EMAIL_L10N=$(tcarlib_getConfigValue)
            if [[ ${EMAIL_L10N} == 'yes' ]];then
                if [[ ${SCRIPT_LANG_LL} != 'en' ]];then
                    EMAIL=$(echo ${EMAIL} | sed "s/@/-${SCRIPT_LANG_LL}@/")
                fi
            fi
            ;;

        email-html )
            local EMAIL_HTML=$(tcarlib_getConfigValue)
            if [[ ${EMAIL_HTML} == 'yes' ]];then
                EMAIL="<a href=\"mailto:${EMAIL}\">${EMAIL_TITLE}</a>"
            fi
            ;;

        * )
            tcarlib_printMessage "`eval_gettext "The \\\"\\\$OPTION\\\" option isn't supported."`" --as-error-line
            ;;

    esac

}
