#!/bin/bash
######################################################################
#
#   tcar - The CentOS Artwork Repository
#   Copyright © 2014 The CentOS Artwork SIG
#
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#   General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#   Alain Reguera Delgado <alain.reguera@gmail.com>
#   39 Street No. 4426 Cienfuegos, Cuba.
#
######################################################################

# Standardize the way specific functionalities are exported to tcar.sh
# script environment.
function tcarlib_setModuleEnvironmentScripts {

    # Define the localization domain for this function.
    local TEXTDOMAIN='tcarlib'

    # Define the pattern used to retrieve function names from function
    # files.
    local FUNCTION_PATTERN="^function[[:space:]]+${SCRIPT_MODULE_NAME}(_[[:alnum:]]+)?[[:space:]]+{[[:space:]]*$"

    # Define the list of files.
    local SCRIPT_MODULE_SCRIPT=''
    local SCRIPT_MODULE_SCRIPTS="${SCRIPT_MODULE_INIT_FILE}"
    if [[ -d ${SCRIPT_MODULE_DIR} ]];then
        SCRIPT_MODULE_SCRIPTS="${SCRIPT_MODULE_SCRIPTS}
            $(tcarlib_getFilesList \
                -p "${SCRIPT_MODULE_DIR}/${SCRIPT_MODULE_NAME}_[[:alnum:]]+\.sh$" \
                -t 'f' ${SCRIPT_MODULE_DIR})"
    fi

    # Verify the list of files. If no function file exists for the
    # location specified stop the script execution. Otherwise the
    # script will surely try to execute a function that haven't been
    # exported yet and report an error about it.
    if [[ -z ${SCRIPT_MODULE_SCRIPTS} ]];then
        tcarlib_printMessage "${FUNCNAME}: `gettext "No function file was found."`" --as-error-line
    fi

    # Process the list of files.
    for SCRIPT_MODULE_SCRIPT in ${SCRIPT_MODULE_SCRIPTS};do

        # Verify the execution rights for function file.
        tcarlib_checkFiles -ex ${SCRIPT_MODULE_SCRIPT}

        # Retrieve the function's name from function's file.
        local SCRIPT_MODULE_SCRIPT_FN=$(egrep "${FUNCTION_PATTERN}" ${SCRIPT_MODULE_SCRIPT} \
            | gawk '{ print $2 }')

        # Verify function's name. It cannot be an empty value.
        if [[ -z "${SCRIPT_MODULE_SCRIPT_FN}" ]];then
            tcarlib_printMessage "`gettext "No function definition found."`" --as-error-line
        fi

        # Verify that function files have not been already exported.
        # If they have been already exported don't export them again.
        # Instead, continue with the next function file in the list.
        declare -F | gawk '{ print $3 }' | egrep "^${SCRIPT_MODULE_SCRIPT}$" > /dev/null
        if [[ $? -eq 0 ]];then
            continue
        fi

        # Initialize the function file.
        . ${SCRIPT_MODULE_SCRIPT}

        # Export the function names inside the file to current shell
        # script environment.
        export -f ${SCRIPT_MODULE_SCRIPT_FN}

        tcarlib_printMessage "export -f : ${SCRIPT_MODULE_SCRIPT_FN}" --as-debugger-line

    done

}
